"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.sdkRequest = void 0;

var _onSdkAvailable = require("../../connect/onSdkAvailable.js");

var _index = require("../../v0/src/index.js");

var startLoader = function startLoader(loaderInstance) {
  (0, _onSdkAvailable.onSdkAvailable)(function ($sdk) {
    $sdk.dispatch({
      type: 'START_LOADER',
      loaderInstance: loaderInstance
    });
  });
};

var stopLoader = function stopLoader(loaderInstance) {
  (0, _onSdkAvailable.onSdkAvailable)(function ($sdk) {
    $sdk.dispatch({
      type: 'STOP_LOADER',
      loaderInstance: loaderInstance
    });
  });
};

var errorHandler = function errorHandler(instance, responseOrError) {
  var status = responseOrError.status,
      statusText = responseOrError.statusText,
      data = responseOrError.data;

  if (status != null && statusText != null) {
    if (status >= 400) {
      (0, _onSdkAvailable.onSdkAvailable)(function ($sdk) {
        $sdk.dispatch({
          type: 'SET_INSTANCE_NETWORK_ERROR',
          instance: instance
        });
      });
    } else if (data != null && Array.isArray(data.messages) && data.messages.length > 0) {
      (0, _onSdkAvailable.onSdkAvailable)(function ($sdk) {
        $sdk.dispatch({
          type: 'SET_INSTANCE_ERROR',
          instance: instance,
          errors: data.messages
        });
      });
    } else {
      (0, _onSdkAvailable.onSdkAvailable)(function ($sdk) {
        $sdk.dispatch({
          type: 'CLEAN_INSTANCE_ERROR',
          instance: instance
        });
      });
    }
  }

  return undefined;
};

var requestService = function requestService(requestThunk, instance, token) {
  if (instance) {
    startLoader(instance.id);
  }

  _index.authorization.set(_index.BEARER, token);

  _index.headers.append('Content-type', 'application/json');

  return requestThunk().then(function (data) {
    if (instance) {
      stopLoader(instance.id);
      errorHandler(instance.id, data);
    }

    return data;
  })["catch"](function () {
    if (instance) {
      stopLoader(instance.id);
      (0, _onSdkAvailable.onSdkAvailable)(function ($sdk) {
        $sdk.dispatch({
          type: 'SET_INSTANCE_NETWORK_ERROR',
          instance: instance.id
        });
      });
    }
  });
};

var sdkRequest = function sdkRequest(requestThunk, instance, token) {
  return requestService(requestThunk, instance, token);
};

exports.sdkRequest = sdkRequest;