"use strict";

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(source, true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(source).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

function _toConsumableArray(arr) { return _arrayWithoutHoles(arr) || _iterableToArray(arr) || _nonIterableSpread(); }

function _nonIterableSpread() { throw new TypeError("Invalid attempt to spread non-iterable instance"); }

function _iterableToArray(iter) { if (Symbol.iterator in Object(iter) || Object.prototype.toString.call(iter) === "[object Arguments]") return Array.from(iter); }

function _arrayWithoutHoles(arr) { if (Array.isArray(arr)) { for (var i = 0, arr2 = new Array(arr.length); i < arr.length; i++) { arr2[i] = arr[i]; } return arr2; } }

function _slicedToArray(arr, i) { return _arrayWithHoles(arr) || _iterableToArrayLimit(arr, i) || _nonIterableRest(); }

function _nonIterableRest() { throw new TypeError("Invalid attempt to destructure non-iterable instance"); }

function _iterableToArrayLimit(arr, i) { if (!(Symbol.iterator in Object(arr) || Object.prototype.toString.call(arr) === "[object Arguments]")) { return; } var _arr = []; var _n = true; var _d = false; var _e = undefined; try { for (var _i = arr[Symbol.iterator](), _s; !(_n = (_s = _i.next()).done); _n = true) { _arr.push(_s.value); if (i && _arr.length === i) break; } } catch (err) { _d = true; _e = err; } finally { try { if (!_n && _i["return"] != null) _i["return"](); } finally { if (_d) throw _e; } } return _arr; }

function _arrayWithHoles(arr) { if (Array.isArray(arr)) return arr; }

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.feesModel = exports.putMerchantsBankInfo = exports.bankInfoModel = exports.infoModel = exports.addressesModel = exports.putContactsModel = exports.contactsModel = exports.partnersModel = void 0;

var _slingHelpers = require("sling-helpers");

var partnersModel = function partnersModel(data) {
  var modeledData = data.map(function (item) {
    return {
      name: item.name,
      email: item.email,
      rg: item.rg,
      cpf: item.cpf
    };
  });
  return modeledData;
};

exports.partnersModel = partnersModel;

var contactsModel = function contactsModel(data) {
  return data;
};

exports.contactsModel = contactsModel;

var putContactsModel = function putContactsModel(data) {
  var modeledData = {
    name: data.name,
    typeId: Number(data.typeId),
    email: data.email,
    phone: (0, _slingHelpers.replaceNonDigits)(data.phone),
    mobilePhone: (0, _slingHelpers.replaceNonDigits)(data.mobilePhone)
  };
  return modeledData;
};

exports.putContactsModel = putContactsModel;

var addressesModel = function addressesModel(data) {
  var modeledData = data.map(function (item) {
    return {
      description: item.typeName,
      uf: item.stateName,
      city: item.cityName,
      street: item.streetName,
      number: item.streetNumber,
      complement: item.complement,
      neighborhood: item.neighborhood
    };
  });
  return modeledData;
};

exports.addressesModel = addressesModel;

var infoModel = function infoModel(data, stonecode) {
  var modeledData = [{
    stonecode: stonecode,
    cnpj: data.document,
    companyName: data.companyName,
    fantasyName: data.fantasyName,
    mccDescription: data.mccDescription
  }];
  return modeledData;
};

exports.infoModel = infoModel;

var bankInfoModel = function bankInfoModel(responses) {
  var _responses = _slicedToArray(responses, 2),
      availableBanks = _responses[0],
      banks = _responses[1];

  var modeledData = {
    banks: banks.data,
    availableBanks: availableBanks.data
  };
  modeledData.banks = modeledData.banks.reduce(function (result, current) {
    var repeatedAccountNumbers = result.map(function (item) {
      return item.accountNumber;
    });
    var repeatedAgencyNumbers = result.map(function (item) {
      return item.agencyNumber;
    });
    var repeatedBankIds = result.map(function (item) {
      return item.bankId;
    });

    if (repeatedAccountNumbers.includes(current.accountNumber) && repeatedAgencyNumbers.includes(current.agencyNumber) && repeatedBankIds.includes(current.bankId)) {
      return result;
    }

    return [].concat(_toConsumableArray(result), [current]);
  }, []);
  return modeledData;
};

exports.bankInfoModel = bankInfoModel;

var putMerchantsBankInfo = function putMerchantsBankInfo(data) {
  var modeledPayload = {
    accountNumber: data.accountNumber,
    accountNumberVerificationCode: data.accountNumberVerificationCode,
    agencyNumber: data.agencyNumber,
    agencyNumberVerificationCode: data.agencyNumberVerificationCode,
    bankId: Number(data.bankId),
    statusId: Number(data.statusId),
    typeId: Number(data.typeId),
    centralizedPayment: data.centralizedPayment
  };
  return modeledPayload;
};

exports.putMerchantsBankInfo = putMerchantsBankInfo;

var feesModel = function feesModel(_ref) {
  var _ref2 = _slicedToArray(_ref, 3),
      transactionProfilesResp = _ref2[0],
      cardBrandsResp = _ref2[1],
      merchantFeesResp = _ref2[2];

  var byTransactionProfileId = function byTransactionProfileId(id) {
    return function (item) {
      return item.transactionProfileId !== id;
    };
  };

  var byCardBrandIdOf = function byCardBrandIdOf(item) {
    return function (cardBrand) {
      return cardBrand.id === item.cardBrandId;
    };
  };

  var byTransactionProfileIdOf = function byTransactionProfileIdOf(item) {
    return function (transactionProfile) {
      return transactionProfile.id === item.transactionProfileId;
    };
  };

  var boletoId = 10;
  var transactionProfiles = transactionProfilesResp.data;
  var cardBrands = cardBrandsResp.data;
  var merchantFees = merchantFeesResp.data.filter(byTransactionProfileId(boletoId)).map(function (merchantFee) {
    return _objectSpread({}, merchantFee, {
      cardBrandName: cardBrands.find(byCardBrandIdOf(merchantFee)).name,
      transactionProfileName: transactionProfiles.find(byTransactionProfileIdOf(merchantFee)).name
    });
  });
  return merchantFees;
};

exports.feesModel = feesModel;