"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.connect = void 0;

var _slingHelpers = require("sling-helpers");

var _onSdkAccessible = require("./onSdkAccessible.js");

const connect = (mapStateToProps, mapDispatchToProps) => (Base = HTMLElement) => {
  class ConnectedComponent extends Base {
    constructor() {
      super();
      this.handleStoreChange = this.handleStoreChange.bind(this);
    }

    handleStoreChange($sdk) {
      const state = $sdk.store.getState();
      const {
        dispatch
      } = $sdk.store;
      const newProps = (0, _slingHelpers.isFunction)(mapStateToProps) ? mapStateToProps(state, this) : {};
      const newActions = (0, _slingHelpers.isFunction)(mapDispatchToProps) ? mapDispatchToProps(dispatch, this) : {};
      Object.entries({ ...newProps,
        ...newActions
      }).forEach(([prop, value]) => {
        if (!(0, _slingHelpers.isFunction)(this[prop])) {
          this[prop] = value;
        }
      });
    }

    connectedCallback() {
      if ((0, _slingHelpers.isFunction)(super.connectedCallback)) {
        super.connectedCallback();
      }

      (0, _onSdkAccessible.onSdkAccessible)().then($sdk => {
        this.unsubscribe = $sdk.store.subscribe(() => {
          this.handleStoreChange($sdk);
        });
        this.handleStoreChange($sdk);
      });
    }

    disconnectedCallback() {
      if ((0, _slingHelpers.isFunction)(super.disconnectedCallback)) {
        super.disconnectedCallback();
      }

      if ((0, _slingHelpers.isFunction)(this.unsubscribe)) {
        this.unsubscribe();
      }
    }

  }

  return ConnectedComponent;
};

exports.connect = connect;