"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.getMerchantFees = exports.updateBankAccounts = exports.getMerchantBankInfo = exports.patchMerchantInfo = exports.getMerchantInfo = exports.getMerchantAddresses = exports.getMerchantPartners = exports.putMerchantContacts = exports.getMerchantContacts = void 0;

var merchantService = _interopRequireWildcard(require("../../core/services/merchantService.js"));

var merchantModel = _interopRequireWildcard(require("../../models/merchantModels.js"));

var transactionsService = _interopRequireWildcard(require("../../core/services/transactionsService.js"));

function _getRequireWildcardCache() { if (typeof WeakMap !== "function") return null; var cache = new WeakMap(); _getRequireWildcardCache = function () { return cache; }; return cache; }

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

const getMerchantContacts = (requestParams, instance) => dispatch => {
  merchantService.getContacts(requestParams, instance).then(response => {
    dispatch({
      type: 'GET_MERCHANT_CONTACTS',
      data: merchantModel.contactsModel(response.data)
    });
  });
};

exports.getMerchantContacts = getMerchantContacts;

const putMerchantContacts = (requestParams, instance) => dispatch => {
  merchantService.putContacts(requestParams, instance).then(response => {
    dispatch({
      type: 'PUT_MERCHANT_CONTACTS',
      data: response.data
    });
  });
};

exports.putMerchantContacts = putMerchantContacts;

const getMerchantPartners = (requestParams, instance) => dispatch => {
  merchantService.getPartners(requestParams, instance).then(response => {
    dispatch({
      type: 'GET_MERCHANT_PARTNERS',
      data: merchantModel.partnersModel(response)
    });
  });
};

exports.getMerchantPartners = getMerchantPartners;

const getMerchantAddresses = (requestParams, instance) => dispatch => {
  merchantService.getAddresses(requestParams, instance).then(response => {
    dispatch({
      type: 'GET_MERCHANT_ADDRESSES',
      data: merchantModel.addressesModel(response.data)
    });
  });
};

exports.getMerchantAddresses = getMerchantAddresses;

const getMerchantInfo = (requestParams, instance) => dispatch => {
  merchantService.getInfo(requestParams, instance).then(response => {
    dispatch({
      type: 'GET_MERCHANT_INFO',
      data: merchantModel.infoModel(response.data, requestParams.stonecode)
    });
  });
};

exports.getMerchantInfo = getMerchantInfo;

const patchMerchantInfo = (requestParams, instance) => dispatch => {
  merchantService.patchInfo(requestParams, instance).then(response => {
    dispatch({
      type: 'PATCH_MERCHANT_FANTASY_NAME',
      data: response.data.fantasyName
    });
  });
};

exports.patchMerchantInfo = patchMerchantInfo;

const getMerchantBankInfo = (requestParams, instance) => dispatch => {
  const promises = [merchantService.getAvailableBanks(requestParams, instance), merchantService.getBankInfo(requestParams, instance)];
  Promise.all(promises).then(responses => {
    dispatch({
      type: 'GET_MERCHANT_BANK_INFO',
      data: merchantModel.bankInfoModel(responses)
    });
  });
};

exports.getMerchantBankInfo = getMerchantBankInfo;

const updateBankAccounts = (requestParams, instance) => dispatch => {
  merchantService.putBankAccounts(requestParams, instance).then(response => {
    dispatch({
      type: 'PUT_MERCHANT_BANK_INFO',
      data: response.data
    });
  });
};

exports.updateBankAccounts = updateBankAccounts;

const getMerchantFees = (requestParams, instance) => dispatch => {
  const promises = [transactionsService.getTransactionProfiles(requestParams, instance), transactionsService.getBrands(requestParams, instance), merchantService.getFees(requestParams, instance)];
  Promise.all(promises).then(responses => {
    dispatch({
      type: 'GET_MERCHANT_FEES',
      data: merchantModel.feesModel(responses)
    });
  });
};

exports.getMerchantFees = getMerchantFees;