"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.makeRequest = exports.defaultErrorHandler = exports.defaultBodyParser = exports.defaultResponseParser = exports.defaultStatusChecker = void 0;

const defaultStatusChecker = response => response.ok;

exports.defaultStatusChecker = defaultStatusChecker;

const defaultResponseParser = response => response.status !== 204 ? response.json() : response;

exports.defaultResponseParser = defaultResponseParser;

const defaultBodyParser = body => JSON.stringify(body);

exports.defaultBodyParser = defaultBodyParser;

const defaultErrorHandler = error => error;

exports.defaultErrorHandler = defaultErrorHandler;

const makeRequest = (url, requestParams = {}, requestConfig = {}, fetchMaker = fetch) => {
  const {
    statusChecker = defaultStatusChecker,
    responseParser = defaultResponseParser,
    bodyParser = defaultBodyParser,
    errorHandler = defaultErrorHandler
  } = requestConfig;
  const {
    body
  } = requestParams;
  let requestParamsWithParsedBody = requestParams;

  if (body != null) {
    requestParamsWithParsedBody = { ...requestParams,
      body: bodyParser(body)
    };
  }

  return fetchMaker(url, requestParamsWithParsedBody).then(response => {
    if (statusChecker(response) === true) {
      return responseParser(response);
    }

    throw errorHandler(response);
  }).catch(error => {
    throw errorHandler(error);
  });
};

exports.makeRequest = makeRequest;