function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(source, true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(source).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

function _slicedToArray(arr, i) { return _arrayWithHoles(arr) || _iterableToArrayLimit(arr, i) || _nonIterableRest(); }

function _nonIterableRest() { throw new TypeError("Invalid attempt to destructure non-iterable instance"); }

function _iterableToArrayLimit(arr, i) { if (!(Symbol.iterator in Object(arr) || Object.prototype.toString.call(arr) === "[object Arguments]")) { return; } var _arr = []; var _n = true; var _d = false; var _e = undefined; try { for (var _i = arr[Symbol.iterator](), _s; !(_n = (_s = _i.next()).done); _n = true) { _arr.push(_s.value); if (i && _arr.length === i) break; } } catch (err) { _d = true; _e = err; } finally { try { if (!_n && _i["return"] != null) _i["return"](); } finally { if (_d) throw _e; } } return _arr; }

function _arrayWithHoles(arr) { if (Array.isArray(arr)) return arr; }

function _toConsumableArray(arr) { return _arrayWithoutHoles(arr) || _iterableToArray(arr) || _nonIterableSpread(); }

function _nonIterableSpread() { throw new TypeError("Invalid attempt to spread non-iterable instance"); }

function _iterableToArray(iter) { if (Symbol.iterator in Object(iter) || Object.prototype.toString.call(iter) === "[object Arguments]") return Array.from(iter); }

function _arrayWithoutHoles(arr) { if (Array.isArray(arr)) { for (var i = 0, arr2 = new Array(arr.length); i < arr.length; i++) { arr2[i] = arr[i]; } return arr2; } }

import moment from 'moment/moment';
import { groupByDeep } from 'sling-helpers';
var emptyString = '---'; // get status value by reference id

var formatStatus = function formatStatus(paymentsStatus, id) {
  var status = paymentsStatus.data.find(function (item) {
    return item.id === id;
  });
  return status.name || emptyString;
}; // get movement category value by reference id


var formatMovementCategory = function formatMovementCategory(operationsCategories, id) {
  var movementCategory = operationsCategories.data.find(function (item) {
    return item.id === id;
  });
  return movementCategory.name || emptyString;
}; // format product type by product_id + installments


var formatProductType = function formatProductType(productTypes, item) {
  if (!item.productTypeId || !item.installments) {
    return emptyString;
  }

  var productType = productTypes.data.find(function (type) {
    return type.id === item.productTypeId;
  });
  return "".concat(productType.name, " ").concat(item.installments, "x");
};

var getNames = function getNames(walletTypeId, walletTypes, productTypes, brands) {
  var _walletTypes$data$fin = walletTypes.data.find(function (item) {
    return item.id === walletTypeId;
  }),
      brandId = _walletTypes$data$fin.brandId,
      productTypeId = _walletTypes$data$fin.productTypeId,
      walletTypeName = _walletTypes$data$fin.name;

  var _ref = brands.data.find(function (item) {
    return item.id === brandId;
  }) || {
    name: 'Stone'
  },
      brandName = _ref.name;

  var _productTypes$data$fi = productTypes.data.find(function (item) {
    return item.id === productTypeId;
  }),
      productType = _productTypes$data$fi.name;

  return {
    brandName: brandName,
    productType: productType,
    walletTypeName: walletTypeName
  };
};

var mergePropsBy = function mergePropsBy(propName, mergeFn) {
  return function (result, current) {
    var itemsSoFar = result.map(function (item) {
      return item[propName];
    });
    return itemsSoFar.includes(current[propName]) ? result.map(function (item) {
      return mergeFn(item, current, propName);
    }) : [].concat(_toConsumableArray(result), [current]);
  };
};

export var paymentsCalendarModel = function paymentsCalendarModel(responses) {
  var _responses = _slicedToArray(responses, 2),
      calendarData = _responses[0],
      paymentsStatus = _responses[1];

  var groupAndSumPaymentsWithSameSettlementStatus = function groupAndSumPaymentsWithSameSettlementStatus(groupedDataByDate) {
    var entries = Object.entries(groupedDataByDate);
    var resultData = {}; // iterate through each day

    entries.forEach(function (element) {
      // get day informations
      var values = element[1]; // reduce day informations with same settlement_status_id

      resultData[element[0]] = values.reduce(function (result, value) {
        var alreadyHasSettlementStatus = result.find(function (item) {
          return item.settlement_status_id === value.settlement_status_id;
        });

        if (!alreadyHasSettlementStatus) {
          result.push(value);
        } else {
          alreadyHasSettlementStatus.amount += value.amount;
        }

        return result;
      }, []);
    });
    return resultData;
  }; // map api data response


  var mapedData = calendarData.data.map(function (item) {
    return {
      // api date response comes as UTC iso string (2018-07-02T00:00:00.000Z)
      // so the moment formatter must call utc method first
      date: moment(item.referenceDate).utc().format('YYYY-MM-DD'),
      amount: item.amount,
      settlement_status_id: item.settlementStatusId,
      status: formatStatus(paymentsStatus, item.settlementStatusId)
    };
  });
  var groupedDataByDate = groupByDeep(mapedData, function (item) {
    return item.date;
  });
  return groupAndSumPaymentsWithSameSettlementStatus(groupedDataByDate);
};
var groupAndSumAmountsWithSameWalletTypeId = mergePropsBy('walletTypeId', function (item, current, propName) {
  return item[propName] === current[propName] ? _objectSpread({}, item, {
    amount: item.amount + current.amount
  }) : item;
});
export var paymentDetailsModel = function paymentDetailsModel(responses) {
  var _responses2 = _slicedToArray(responses, 4),
      paymentsDetails = _responses2[0],
      walletTypes = _responses2[1],
      brands = _responses2[2],
      productTypes = _responses2[3];

  var paymentDetailsMapper = function paymentDetailsMapper(paymentDetail) {
    var amount = paymentDetail.amount,
        walletTypeId = paymentDetail.walletTypeId,
        settlementStatusId = paymentDetail.settlementStatusId;

    var _ref2 = walletTypes.data.find(function (item) {
      return item.id === walletTypeId;
    }) || [],
        brandId = _ref2.brandId;

    var _ref3 = getNames(walletTypeId, walletTypes, productTypes, brands) || [],
        productType = _ref3.productType,
        name = _ref3.walletTypeName,
        brandName = _ref3.brandName;

    return {
      amount: amount,
      walletTypeId: walletTypeId,
      settlementStatusId: settlementStatusId,
      brandId: brandId,
      productType: productType,
      name: name,
      brandName: brandName
    };
  };

  var payments = paymentsDetails.data.map(paymentDetailsMapper);
  var groupedBalance = payments.reduce(groupAndSumAmountsWithSameWalletTypeId, []);
  var groupedTotal = payments.filter(function (payment) {
    return payment.settlementStatusId === 4;
  }).reduce(groupAndSumAmountsWithSameWalletTypeId, []);
  var result = groupByDeep(groupedBalance, function (item) {
    return item.walletTypeId === 1 ? 'other' : 'summary';
  });
  result.summary = groupByDeep(result.summary, function (item) {
    return item.brandId;
  });
  result.total = [{
    name: 'Saldo',
    amount: groupedBalance.reduce(function (sum, current) {
      return sum + current.amount;
    }, 0)
  }, {
    name: 'Total pago',
    amount: groupedTotal.reduce(function (sum, current) {
      return sum + current.amount;
    }, 0)
  }];
  return [result];
};
var groupAndSumAmountsWithSameMovementCategoryId = mergePropsBy('movementCategoryId', function (item, current, propName) {
  return item[propName] === current[propName] ? _objectSpread({}, item, {
    amount: item.amount + current.amount
  }) : item;
});
export var paymentDetailsByWalletTypeIdModel = function paymentDetailsByWalletTypeIdModel(responses) {
  var _responses3 = _slicedToArray(responses, 5),
      paymentsDetails = _responses3[0],
      walletTypes = _responses3[1],
      operationsCategories = _responses3[2],
      brands = _responses3[3],
      productTypes = _responses3[4];

  var total = {
    name: 'Saldo final',
    amount: 0
  };
  var result = paymentsDetails.data.map(function (item) {
    var amount = item.amount,
        walletTypeId = item.walletTypeId,
        movementCategoryId = item.movementCategoryId;

    var byMovementCategoryId = function byMovementCategoryId(movement) {
      return movement.id === movementCategoryId;
    };

    var _ref4 = operationsCategories.data.find(byMovementCategoryId) || [],
        movementCategory = _ref4.name;

    var _ref5 = walletTypes.data.find(function (wallet) {
      return wallet.id === walletTypeId;
    }) || [],
        brandId = _ref5.brandId;

    var _ref6 = getNames(walletTypeId, walletTypes, productTypes, brands) || [],
        productType = _ref6.productType,
        walletTypeName = _ref6.walletTypeName,
        brandName = _ref6.brandName;

    total.amount += amount;
    return {
      amount: amount,
      brandId: brandId,
      productType: productType,
      walletTypeName: walletTypeName,
      movementCategory: movementCategory,
      movementCategoryId: movementCategoryId,
      brandName: brandName
    };
  }).reduce(groupAndSumAmountsWithSameMovementCategoryId, []);
  result.total = [total];
  return result;
};
export var paymentOperationsModel = function paymentOperationsModel(responses) {
  var _responses4 = _slicedToArray(responses, 4),
      operationsData = _responses4[0],
      paymentsStatus = _responses4[1],
      operationsCategories = _responses4[2],
      productTypes = _responses4[3];

  var result = {
    total: operationsData.total
  };
  result.data = operationsData.data.map(function (item) {
    return {
      operation_date: item.operationDate,
      reference_date: item.referenceDate,
      category: formatMovementCategory(operationsCategories, item.movementCategoryId),
      gross_amount: item.grossAmount,
      brand_id: item.brandId,
      transaction_key: item.transactionKey,
      net_amount: item.netAmount,
      installment_number: item.installmentNumber,
      settlement_status_id: item.settlementStatusId,
      status: formatStatus(paymentsStatus, item.settlementStatusId),
      product: formatProductType(productTypes, item)
    };
  });
  return result;
};
export var paymentsWalletsTypesModel = function paymentsWalletsTypesModel(data) {
  return data;
};
export var paymentsStatusModel = function paymentsStatusModel(data) {
  return data;
};
export var paymentsOperationsCategoriesModel = function paymentsOperationsCategoriesModel(data) {
  return data;
};