const initialState = {
  loaders: {},
  errors: [],
};

const startLoader = (state, action) => {
  const { loaderInstance } = action;

  return {
    ...state,
    loaders: {
      ...state.loaders,
      [loaderInstance]: (state.loaders[loaderInstance] || 0) + 1,
    },
  };
};

const stopLoader = (state, action) => {
  const { loaderInstance } = action;

  return {
    ...state,
    loaders: {
      ...state.loaders,
      [loaderInstance]: (state.loaders[loaderInstance] || 0) - 1,
    },
  };
};

const setError = (state, action) => ({
  ...state,
  errors: {
    ...state.errors,
    [action.instance]: action.errors,
  },
});

const setNetworkError = (state, action) => ({
  ...state,
  errors: {
    ...state.errors,
    [action.instance]: ['Ocorreu um erro no carregamento dos dados'],
  },
});

const cleanInstanceError = (state, action) => ({
  ...state,
  errors: {
    ...state.errors,
    [action.instance]: [],
  },
});

export const globalReducer = (state = initialState, action = {}) => {
  switch (action.type) {
    case 'START_LOADER': {
      return startLoader(state, action);
    }
    case 'STOP_LOADER': {
      return stopLoader(state, action);
    }
    case 'SET_INSTANCE_ERROR': {
      return setError(state, action);
    }
    case 'SET_INSTANCE_NETWORK_ERROR': {
      return setNetworkError(state, action);
    }
    case 'CLEAN_INSTANCE_ERROR': {
      return cleanInstanceError(state, action);
    }
    default:
      return state;
  }
};
