import { BEFORE_REQUEST, AFTER_REQUEST } from './constants.js';

const isObject = arg => typeof arg === 'object' &&
  !Array.isArray(arg) &&
  arg != null;

const isFunction = arg => typeof arg === 'function';
const isPromise = arg => arg != null && isFunction(arg.then);

export const validateMiddleware = (middleware) => {
  if (!isObject(middleware)) {
    throw new Error('The middleware must be an object.');
  }

  const hasWrongPropery = Object
    .keys(middleware)
    .some(key => ![BEFORE_REQUEST, AFTER_REQUEST].includes(key));

  if (hasWrongPropery) {
    throw new Error(`The middleware can only have ${BEFORE_REQUEST} and ` +
      `${AFTER_REQUEST} properties`);
  }

  const hasWrongPropertyTypes = Object
    .values(middleware)
    .some(key => !isFunction(key) && !isPromise(key));

  if (hasWrongPropertyTypes) {
    throw new Error(`The middleware can only have ${BEFORE_REQUEST} and ` +
      `${AFTER_REQUEST} properties, which should be functions.`);
  }

  return middleware;
};
