const { readFile } = require('fs-extra');

const getJsPathsExceptTests = require('./helpers/getJsPathsExceptTests');
const bundleJsImports = require('./helpers/bundleJsImports');
const transformImportToCjs = require('./helpers/transformImportToCjs');
const transformEs6ToEs5 = require('./helpers/transformEs6ToEs5');
const safeWriteFile = require('./helpers/safeWriteFile');

console.log('Building');

(async () => {
  console.log('Started');

  let context;

  // Outputs `dist/es/es6/` and `dist/es/es5/` from `src/`

  context = await getJsPathsExceptTests('./src');

  await Promise.all(context.map((filePath) => {
    const es6Path = filePath.replace('/src/', '/dist/es/es6/');
    const es5Path = filePath.replace('/src/', '/dist/es/es5/');

    return readFile(filePath, 'utf8')
      .then(safeWriteFile(es6Path))
      .then(transformEs6ToEs5)
      .then(safeWriteFile(es5Path));
  }));

  // Outputs `dist/cjs/es6/` and `dist/cjs/es5/` from `dist/es/es6/`

  context = await getJsPathsExceptTests('./dist/es/es6');

  await Promise.all(context.map((filePath) => {
    const es6Path = filePath.replace('/dist/es/es6/', '/dist/cjs/es6/');
    const es5Path = filePath.replace('/dist/es/es6/', '/dist/cjs/es5/');

    return readFile(filePath, 'utf8')
      .then(transformImportToCjs)
      .then(safeWriteFile(es6Path))
      .then(transformEs6ToEs5)
      .then(safeWriteFile(es5Path));
  }));

  // Outputs `dist/iife/es6/` and `dist/iife/es5/` from `dist/es/es6/index.js`

  context = ['./dist/es/es6/index.js'];

  await Promise.all(context.map((filePath) => {
    const es6Path = filePath.replace('/dist/es/es6/', '/dist/iife/es6/');
    const es5Path = filePath.replace('/dist/es/es6/', '/dist/iife/es5/');

    return Promise.resolve(filePath)
      .then(bundleJsImports('SlingSdk'))
      .then(safeWriteFile(es6Path))
      .then(transformEs6ToEs5)
      .then(safeWriteFile(es5Path));
  }));

  console.log('Finished');
})();
