import { isFunction } from 'sling-helpers';
import { onSdkAccessible } from './onSdkAccessible.js';

export const connect = (mapStateToProps, mapDispatchToProps) =>
  (Base = HTMLElement) => {
    class ConnectedComponent extends Base {
      constructor() {
        super();
        this.handleStoreChange = this.handleStoreChange.bind(this);
      }

      handleStoreChange($sdk) {
        const state = $sdk.store.getState();
        const { dispatch } = $sdk.store;

        const newProps = (isFunction(mapStateToProps))
          ? mapStateToProps(state, this)
          : {};

        const newActions = (isFunction(mapDispatchToProps))
          ? mapDispatchToProps(dispatch, this)
          : {};

        Object.entries({ ...newProps, ...newActions })
          .forEach(([prop, value]) => {
            if (!isFunction(this[prop])) {
              this[prop] = value;
            }
          });
      }

      connectedCallback() {
        if (isFunction(super.connectedCallback)) {
          super.connectedCallback();
        }

        onSdkAccessible()
          .then(($sdk) => {
            this.unsubscribe = $sdk.store.subscribe(() => {
              this.handleStoreChange($sdk);
            });
            this.handleStoreChange($sdk);
          });
      }

      disconnectedCallback() {
        if (isFunction(super.disconnectedCallback)) {
          super.disconnectedCallback();
        }

        if (isFunction(this.unsubscribe)) {
          this.unsubscribe();
        }
      }
    }
    return ConnectedComponent;
  };
