import sinon from 'sinon';
import { service as merchantsService } from './merchant.js';
import { merchantInterface } from './merchantInterface.js';

const urlParams = { affiliationCode: '321321321' };

describe('Affiliation merchant Module', () => {
  it('Should have methods after initialization.', () => {
    const service = merchantsService();
    expect(service.get).to.be.a('function');
    expect(service.patch).to.be.a('function');
  });

  it('Should call get request.', () => {
    const spy = sinon.spy();

    const getRequest = () => spy;

    const service = merchantsService(getRequest);

    service.get(urlParams);

    expect(spy).to.have.been.calledOnce;
  });

  it('Should call get request and return a valid URL.', () => {
    const spy = sinon.spy();

    const getRequest = (makeUrl) => {
      spy(makeUrl(urlParams));
      return () => {};
    };

    const service = merchantsService(getRequest);

    service.get(urlParams);

    expect(spy).to.have.been
      .calledWith('v0/affiliation/merchants/321321321');
  });

  it('Should call get request with valid params.', () => {
    const spy = sinon.spy();

    const getRequest = () => spy;

    const service = merchantsService(getRequest);

    service.get(urlParams);

    expect(spy).to.have.been.calledWith(urlParams);
  });

  it('Should call patch request.', () => {
    const spy = sinon.spy();

    const patchRequest = () => spy;

    const service = merchantsService(undefined, patchRequest);

    service.patch(urlParams, merchantInterface);

    expect(spy.callCount).to.equal(1);
  });

  it('Should call patch request and return a valid URL.', () => {
    const spy = sinon.spy();

    const patchRequest = (makeUrl) => {
      spy(makeUrl(urlParams));
      return () => {};
    };

    const service = merchantsService(undefined, patchRequest);

    service.patch(urlParams, merchantInterface);

    expect(spy).to.have.been
      .calledWith('v0/affiliation/merchants/321321321');
  });

  it('Should call patch request with valid params.', () => {
    const spy = sinon.spy();

    const patchRequest = () => spy;

    const service = merchantsService(undefined, patchRequest);

    service.patch(urlParams, merchantInterface);

    expect(spy).to.have.been.calledWith(urlParams, merchantInterface);
  });
});
