import sinon from 'sinon';

import { service as transactionsService } from './transactions.js';

const params = {
  affiliationCodes: '123456789',
  startDate: '2018-10-01',
  finalDate: '2018-10-10',
  page: 1,
  pageSize: 2,
};

describe('Transactions Module', () => {
  it('Should have methods after initialization.', () => {
    const service = transactionsService();
    expect(service.list).to.be.a('function');
  });

  it('Should call list request.', () => {
    const spy = sinon.spy();

    const getRequest = () => spy;

    const service = transactionsService(getRequest);

    service.list(params);

    expect(spy).to.have.been.calledOnce;
  });

  it('Should call list request and return a valid URL.', () => {
    const spy = sinon.spy();

    const getRequest = (makeUrl) => {
      spy(makeUrl(params));
      return () => {};
    };

    const service = transactionsService(getRequest);

    service.list(params);

    expect(spy).to.have.been
      .calledWith('v0/all-sales/transactions?affiliationCodes=123456789' +
      '&startDate=2018-10-01&finalDate=2018-10-10&page=1&pageSize=2' +
      '&includes=financialMovements');
  });

  it('Should call list request with valid params.', () => {
    const spy = sinon.spy();

    const getRequest = () => spy;

    const service = transactionsService(getRequest);

    service.list(params);

    expect(spy).to.have.been.calledWith(params);
  });
});
