import sinon from 'sinon';
import { service as agreements } from './agreements.js';

const urlParams = { affiliationCode: '321321321' };

describe('Billing Agreements Module', () => {
  it('Should have methods after initialization.', () => {
    const service = agreements();
    expect(service.get).to.be.a('function');
  });

  it('Should call get request.', () => {
    const spy = sinon.spy();

    const getRequest = () => spy;

    const service = agreements(getRequest);

    service.get(urlParams);

    expect(spy).to.have.been.calledOnce;
  });

  it('Should call get request and return a valid URL.', () => {
    const spy = sinon.spy();

    const getRequest = (makeUrl) => {
      spy(makeUrl(urlParams));
      return () => {};
    };

    const service = agreements(getRequest);

    service.get(urlParams);

    expect(spy).to.have.been
      .calledWith('v0/billing/agreements?affiliationCode=321321321');
  });

  it('Should call get request with valid params.', () => {
    const spy = sinon.spy();

    const getRequest = () => spy;

    const service = agreements(getRequest);

    service.get(urlParams);

    expect(spy).to.have.been.calledWith(urlParams);
  });
});
