import sinon from 'sinon';
import { service as challengeService } from './challenge.js';

const urlParams = {};

describe('Credentials Challenge Module', () => {
  it('Should have methods after initialization.', () => {
    const service = challengeService();
    expect(service.post).to.be.a('function');
  });

  it('Should call post request.', () => {
    const spy = sinon.spy();

    const postRequest = () => spy;

    const service = challengeService(postRequest);

    service.post(urlParams);

    expect(spy).to.have.been.calledOnce;
  });

  it('Should call post request and return a valid URL.', () => {
    const spy = sinon.spy();

    const postRequest = (urlString) => {
      spy(urlString);
      return () => {};
    };

    const service = challengeService(postRequest);

    service.post(urlParams);

    expect(spy).to.have.been.calledOnceWith('v0/challenge');
  });

  it('Should call post request with valid params.', () => {
    const spy = sinon.spy();

    const postRequest = () => spy;

    const service = challengeService(postRequest);

    service.post(urlParams);

    expect(spy).to.have.been.calledOnceWith(urlParams);
  });
});
