import sinon from 'sinon';
import { service as oAuthTokenService } from './oAuthToken.js';
import { oAuthTokenInterface } from './oAuthTokenInterface.js';

const urlParams = {};

describe('Credentials OAuth Token Module', () => {
  it('Should have methods after initialization.', () => {
    const service = oAuthTokenService();
    expect(service.post).to.be.a('function');
  });

  it('Should call post request.', () => {
    const spy = sinon.spy();

    const postRequest = () => spy;

    const service = oAuthTokenService(postRequest);

    service.post(urlParams, oAuthTokenInterface);

    expect(spy).to.have.been.calledOnce;
  });

  it('Should call post request and return a valid URL.', () => {
    const spy = sinon.spy();

    const postRequest = (urlString) => {
      spy(urlString);
      return () => {};
    };

    const service = oAuthTokenService(postRequest);

    service.post(urlParams, oAuthTokenInterface);

    expect(spy).to.have.been.calledOnceWith('v0/oauth/token');
  });

  it('Should call post request with valid params.', () => {
    const spy = sinon.spy();

    const postRequest = () => spy;

    const service = oAuthTokenService(postRequest);

    service.post(urlParams);

    expect(spy).to.have.been.calledOnceWith(urlParams);
  });
});
