import sinon from 'sinon';
import { service as loansService } from './loans.js';

const getUrlParams = {
  document: '333444555',
};

const postUrlParams = {
  document: '07807807807888',
  proposalId: 'qdiyxs',
};

describe('Loans Module', () => {
  it('Should have methods after initialization.', () => {
    const service = loansService();
    expect(service.get).to.be.a('function');
    expect(service.post).to.be.a('function');
  });

  it('Should call get request.', () => {
    const spy = sinon.spy();

    const getRequest = () => spy;

    const service = loansService(getRequest);

    service.get(getUrlParams);

    expect(spy).to.have.been.calledOnce;
  });

  it('Should call get request and return a valid URL.', () => {
    const spy = sinon.spy();

    const getRequest = (makeUrl) => {
      spy(makeUrl(getUrlParams));
      return () => {};
    };

    const service = loansService(getRequest);

    service.get(getUrlParams);

    expect(spy).to.have.been.calledWith(
      'v0/credit/333444555/loans');
  });

  it('Should call get request with valid params.', () => {
    const spy = sinon.spy();

    const getRequest = () => spy;

    const service = loansService(getRequest);

    service.get(getUrlParams);

    expect(spy).to.have.been.calledWith(getUrlParams);
  });

  it('Should call post request.', () => {
    const spy = sinon.spy();

    const postRequest = () => spy;

    const service = loansService(undefined, postRequest);

    service.post(postUrlParams);

    expect(spy).to.have.been.calledOnce;
  });

  it('Should call post request and return a valid URL.', () => {
    const spy = sinon.spy();

    const postRequest = (makeUrl) => {
      spy(makeUrl(postUrlParams));
      return () => {};
    };

    const service = loansService(undefined, postRequest);

    service.post(postUrlParams);

    expect(spy).to.have.been
      .calledWith('v0/credit/07807807807888/proposals/qdiyxs/loans');
  });

  it('Should call post request with valid params.', () => {
    const spy = sinon.spy();

    const postRequest = () => spy;

    const service = loansService(undefined, postRequest);

    service.post(postUrlParams);

    expect(spy).to.have.been.calledWith(postUrlParams);
  });
});
