import sinon from 'sinon';
import { service as paymentsService } from './payments.js';

const getUrlParams = {
  loanId: '333444555',
  pageNumber: 1,
  pageSize: 5,
};

describe('Payments module', () => {
  it('Should have methods after initialization.', () => {
    const service = paymentsService();
    expect(service.get).to.be.a('function');
  });

  it('Should call get request.', () => {
    const spy = sinon.spy();

    const getRequest = () => spy;

    const service = paymentsService(getRequest);

    service.get(getUrlParams);

    expect(spy).to.have.been.calledOnce;
  });

  it('Should call get request and return a valid URL.', () => {
    const spy = sinon.spy();

    const getRequest = (makeUrl) => {
      spy(makeUrl(getUrlParams));
      return () => {};
    };

    const service = paymentsService(getRequest);

    service.get(getUrlParams);

    expect(spy).to.have.been.calledWith(
      'v0/credit/loans/333444555/payments?PageNumber=1&PageSize=5');
  });

  it('Should call get request with valid params.', () => {
    const spy = sinon.spy();

    const getRequest = () => spy;

    const service = paymentsService(getRequest);

    service.get(getUrlParams);

    expect(spy).to.have.been.calledWith(getUrlParams);
  });
});
