import sinon from 'sinon';
import { service as paymentsForecastService } from './payments_forecast.js';

const getUrlParams = {
  documentId: '111111',
  loanId: '111',
};

describe('Payments Forecast Module', () => {
  it('Should have methods after initialization.', () => {
    const service = paymentsForecastService();
    expect(service.get).to.be.a('function');
  });

  it('Should call get request.', () => {
    const spy = sinon.spy();

    const getRequest = () => spy;

    const service = paymentsForecastService(getRequest);

    service.get(getUrlParams);

    expect(spy).to.have.been.calledOnce;
  });

  it('Should call get request and return a valid URL.', () => {
    const spy = sinon.spy();

    const getRequest = (makeUrl) => {
      spy(makeUrl(getUrlParams));
      return () => {};
    };

    const service = paymentsForecastService(getRequest);

    service.get(getUrlParams);

    expect(spy).to.have.been.calledWith(
      'v0/credit/111/payments-forecast?document=111111');
  });

  it('Should call get request with valid params.', () => {
    const spy = sinon.spy();

    const getRequest = () => spy;

    const service = paymentsForecastService(getRequest);

    service.get(getUrlParams);

    expect(spy).to.have.been.calledWith(getUrlParams);
  });
});
