import sinon from 'sinon';
import { service as proposalsService } from './proposals.js';

const postUrlParams = {
  document: '1111111',
};

describe('Loans Module', () => {
  it('Should have methods after initialization.', () => {
    const service = proposalsService();
    expect(service.post).to.be.a('function');
  });

  it('Should call post request.', () => {
    const spy = sinon.spy();

    const postRequest = () => spy;

    const service = proposalsService(postRequest);

    service.post(postUrlParams);

    expect(spy).to.have.been.calledOnce;
  });

  it('Should call post request and return a valid URL.', () => {
    const spy = sinon.spy();

    const postRequest = (makeUrl) => {
      spy(makeUrl(postUrlParams));
      return () => {};
    };

    const service = proposalsService(postRequest);

    service.post(postUrlParams);

    expect(spy).to.have.been
      .calledWith('v0/credit/1111111/proposals');
  });

  it('Should call post request with valid params.', () => {
    const spy = sinon.spy();

    const postRequest = () => spy;

    const service = proposalsService(postRequest);

    service.post(postUrlParams);

    expect(spy).to.have.been.calledWith(postUrlParams);
  });
});
