import sinon from 'sinon';
import { service as validateService } from './validate';
import { validateInterface } from './validateInterface.js';

const urlParams = {};

describe('Validate Module', () => {
  it('Should have methods after initialization.', () => {
    const service = validateService();
    expect(service.post).to.be.a('function');
  });

  it('Should call post request.', () => {
    const spy = sinon.spy();

    const postRequest = () => spy;

    const service = validateService(postRequest);

    service.post(urlParams, validateInterface);

    expect(spy).to.have.been.calledOnce;
  });

  it('Should call post request and return a valid URL.', () => {
    const spy = sinon.spy();

    const postRequest = (urlString) => {
      spy(urlString);
      return () => {};
    };

    const service = validateService(postRequest);

    service.post(urlParams, validateInterface);

    expect(spy).to.have.been.calledWith('v0/merchants/bank-account/validate');
  });

  it('Should call post request with valid params.', () => {
    const spy = sinon.spy();

    const postRequest = () => spy;

    const service = validateService(postRequest);

    service.post(urlParams);

    expect(spy).to.have.been.calledWith(urlParams);
  });
});
