import sinon from 'sinon';
import { service as captureMethodsService } from './captureMethods.js';

const urlParams = { affiliationCodes: '321321321' };

describe('CaptureMethods Module', () => {
  it('Should have methods after initialization.', () => {
    const service = captureMethodsService();
    expect(service.get).to.be.a('function');
  });

  it('Should call get request.', () => {
    const spy = sinon.spy();

    const getRequest = () => spy;

    const service = captureMethodsService(getRequest);

    service.get(urlParams);

    expect(spy).to.have.been.calledOnce;
  });

  it('Should call get request and return a valid URL.', () => {
    const spy = sinon.spy();

    const getRequest = (makeUrl) => {
      spy(makeUrl(urlParams));
      return () => {};
    };

    const service = captureMethodsService(getRequest);

    service.get(urlParams);

    expect(spy).to.have.been
      .calledWith('v0/capture-methods?affiliationCodes=321321321');
  });

  it('Should call get request with valid params.', () => {
    const spy = sinon.spy();

    const getRequest = () => spy;

    const service = captureMethodsService(getRequest);

    service.get(urlParams);

    expect(spy).to.have.been.calledWith(urlParams);
  });
});
