import sinon from 'sinon';
import { service as isMEIService } from './isMEI';

const getUrlParams = {
  document: '111111',
};

describe('Payments Forecast Module', () => {
  it('Should have methods after initialization.', () => {
    const service = isMEIService();
    expect(service.get).to.be.a('function');
  });

  it('Should call get request.', () => {
    const spy = sinon.spy();

    const getRequest = () => spy;

    const service = isMEIService(getRequest);

    service.get(getUrlParams);

    expect(spy).to.have.been.calledOnce;
  });

  it('Should call get request and return a valid URL.', () => {
    const spy = sinon.spy();

    const getRequest = (makeUrl) => {
      spy(makeUrl(getUrlParams));
      return () => {};
    };

    const service = isMEIService(getRequest);

    service.get(getUrlParams);

    expect(spy).to.have.been.calledWith('v0/merchants/111111/is-mei');
  });

  it('Should call get request with valid params.', () => {
    const spy = sinon.spy();

    const getRequest = () => spy;

    const service = isMEIService(getRequest);

    service.get(getUrlParams);

    expect(spy).to.have.been.calledWith(getUrlParams);
  });
});
