import sinon from 'sinon';
import { service as openBalanceService } from './openBalance.js';

const urlParams = {
  affiliationCode: '321321321',
  referenceDate: '2018-12-01',
};

describe('Info List Module', () => {
  it('Should have methods after initialization.', () => {
    const service = openBalanceService();
    expect(service.get).to.be.a('function');
  });

  it('Should call get request.', () => {
    const spy = sinon.spy();

    const getRequest = () => spy;

    const service = openBalanceService(getRequest);

    service.get(urlParams);

    expect(spy).to.have.been.calledOnce;
  });

  it('Should call get request and return a valid URL.', () => {
    const spy = sinon.spy();

    const getRequest = (makeUrl) => {
      spy(makeUrl(urlParams));
      return () => {};
    };

    const service = openBalanceService(getRequest);

    service.get(urlParams);

    expect(spy).to.have.been
      .calledWith('v0/merchants/321321321/open-balance' +
      '?referenceDate=2018-12-01');
  });

  it('Should call get request with valid params.', () => {
    const spy = sinon.spy();

    const getRequest = () => spy;

    const service = openBalanceService(getRequest);

    service.get(urlParams);

    expect(spy).to.have.been.calledWith(urlParams);
  });
});
