import sinon from 'sinon';
import { service as paymentInfoService } from './paymentInfo.js';

const urlParams = {
  affiliationKey: '321abc321abc321',
  startDate: '2018-12-01',
  finalDate: '2018-12-15',
};

describe('Payment Info Module', () => {
  it('Should have methods after initialization.', () => {
    const service = paymentInfoService();
    expect(service.get).to.be.a('function');
  });

  it('Should call get request.', () => {
    const spy = sinon.spy();

    const getRequest = () => spy;

    const service = paymentInfoService(getRequest);

    service.get(urlParams);

    expect(spy).to.have.been.calledOnce;
  });

  it('Should call get request and return a valid URL.', () => {
    const spy = sinon.spy();

    const getRequest = (makeUrl) => {
      spy(makeUrl(urlParams));
      return () => {};
    };

    const service = paymentInfoService(getRequest);

    service.get(urlParams);

    expect(spy).to.have.been
      .calledWith('v0/merchants/321abc321abc321/payment-information?startDate=2018-12-01&finalDate=2018-12-15');
  });

  it('Should call get request with valid params.', () => {
    const spy = sinon.spy();

    const getRequest = () => spy;

    const service = paymentInfoService(getRequest);

    service.get(urlParams);

    expect(spy).to.have.been.calledWith(urlParams);
  });
});
