import sinon from 'sinon';
import { service as paymentsPerDateService } from './paymentsPerDate.js';

const urlParams = {
  affiliationCode: '321321321',
  startDate: '2018-12-01',
  finalDate: '2018-12-15',
};

describe('Info List Module', () => {
  it('Should have methods after initialization.', () => {
    const service = paymentsPerDateService();
    expect(service.get).to.be.a('function');
  });

  it('Should call get request.', () => {
    const spy = sinon.spy();

    const getRequest = () => spy;

    const service = paymentsPerDateService(getRequest);

    service.get(urlParams);

    expect(spy).to.have.been.calledOnce;
  });

  it('Should call get request and return a valid URL.', () => {
    const spy = sinon.spy();

    const getRequest = (makeUrl) => {
      spy(makeUrl(urlParams));
      return () => {};
    };

    const service = paymentsPerDateService(getRequest);

    service.get(urlParams);

    expect(spy).to.have.been
      .calledWith('v0/merchants/321321321/payments-per-date-and-status' +
      '?startDate=2018-12-01&finalDate=2018-12-15');
  });

  it('Should call get request with valid params.', () => {
    const spy = sinon.spy();

    const getRequest = () => spy;

    const service = paymentsPerDateService(getRequest);

    service.get(urlParams);

    expect(spy).to.have.been.calledWith(urlParams);
  });
});
