import sinon from 'sinon';
import { service as preAuthorizationService } from './preAuthorization.js';
import { PreAuthorizationInterface } from './preAuthorizationInterface.js';

const urlParams = {
  affiliationCode: '321321321',
};

describe('Pre Authorization Module', () => {
  it('Should have methods after initialization.', () => {
    const service = preAuthorizationService();
    expect(service.get).to.be.a('function');
    expect(service.put).to.be.a('function');
  });

  it('Should call get request.', () => {
    const spy = sinon.spy();

    const getRequest = () => spy;

    const service = preAuthorizationService(getRequest);

    service.get(urlParams);

    expect(spy).to.have.been.calledOnce;
  });

  it('Should call get request and return a valid URL.', () => {
    const spy = sinon.spy();

    const getRequest = (makeUrl) => {
      spy(makeUrl(urlParams));
      return () => {};
    };

    const service = preAuthorizationService(getRequest);

    service.get(urlParams);

    expect(spy).to.have.been
      .calledWith('v0/merchants/321321321/pre-authorization');
  });

  it('Should call get request with valid params.', () => {
    const spy = sinon.spy();

    const getRequest = () => spy;

    const service = preAuthorizationService(getRequest);

    service.get(urlParams);

    expect(spy).to.have.been.calledWith(urlParams);
  });


  it('Should call put request.', () => {
    const spy = sinon.spy();

    const putRequest = () => spy;

    const service = preAuthorizationService(undefined, putRequest);

    service.put(urlParams, PreAuthorizationInterface);

    expect(spy).to.have.been.calledOnce;
  });

  it('Should call put request and return a valid URL.', () => {
    const spy = sinon.spy();

    const putRequest = (makeUrl) => {
      spy(makeUrl(urlParams));
      return () => {};
    };

    const service = preAuthorizationService(undefined, putRequest);

    service.put(urlParams, PreAuthorizationInterface);

    expect(spy).to.have.been
      .calledWith('v0/merchants/321321321/pre-authorization');
  });

  it('Should call put request with valid params.', () => {
    const spy = sinon.spy();

    const putRequest = () => spy;

    const service = preAuthorizationService(undefined, putRequest);

    service.put(urlParams);

    expect(spy).to.have.been.calledWith(urlParams);
  });
});
