import sinon from 'sinon';
import { service as rentedTerminalsService } from './rentedTerminals.js';

const urlParams = {
  affiliationCode: '321321321',
};

describe('Rented terminals Module', () => {
  it('Should have methods after initialization.', () => {
    const service = rentedTerminalsService();
    expect(service.get).to.be.a('function');
  });

  it('Should call get request.', () => {
    const spy = sinon.spy();

    const getRequest = () => spy;

    const service = rentedTerminalsService(getRequest);

    service.get(urlParams);

    expect(spy).to.have.been.calledOnce;
  });

  it('Should call get request and return a valid URL.', () => {
    const spy = sinon.spy();

    const getRequest = (makeUrl) => {
      spy(makeUrl(urlParams));
      return () => {};
    };

    const service = rentedTerminalsService(getRequest);

    service.get(urlParams);

    expect(spy).to.have.been
      .calledWith('v0/merchants/321321321/terminals');
  });

  it('Should call get request with valid params.', () => {
    const spy = sinon.spy();

    const getRequest = () => spy;

    const service = rentedTerminalsService(getRequest);

    service.get(urlParams);

    expect(spy).to.have.been.calledWith(urlParams);
  });

  it('Should call return a valid URL when terminalID is present.', () => {
    const spy = sinon.spy();
    urlParams.terminalId = 123;

    const getRequest = (makeUrl) => {
      spy(makeUrl(urlParams));
      return () => {};
    };

    const service = rentedTerminalsService(getRequest);

    service.get(urlParams);

    expect(spy).to.have.been
      .calledWith('v0/merchants/321321321/terminals?terminalId=123');
  });
});
