import sinon from 'sinon';
import { service as rentsPerDateService } from './rentsPerDate.js';

const urlParams = {
  affiliationCode: '321321321',
  startDate: '2019-01-01T00:00:00',
  endDate: '2019-02-10T08:07:00',
};

describe('Info List Module', () => {
  it('Should have methods after initialization.', () => {
    const service = rentsPerDateService();
    expect(service.get).to.be.a('function');
  });

  it('Should call get request.', () => {
    const spy = sinon.spy();

    const getRequest = () => spy;

    const service = rentsPerDateService(getRequest);

    service.get(urlParams);

    expect(spy).to.have.been.calledOnce;
  });

  it('Should call get request and return a valid URL.', () => {
    const spy = sinon.spy();

    const getRequest = (makeUrl) => {
      spy(makeUrl(urlParams));
      return () => {};
    };

    const service = rentsPerDateService(getRequest);

    service.get(urlParams);

    expect(spy).to.have.been
      .calledWith('v0/merchants/321321321/rents' +
      '?aspNetAjaxChargeDateFrom=/Date(1546308000000%2B0000)/' +
      '&aspNetAjaxChargeDateTo=/Date(1549793220000%2B0000)/');
  });

  it('Should call get request with valid params.', () => {
    const spy = sinon.spy();

    const getRequest = () => spy;

    const service = rentsPerDateService(getRequest);

    service.get(urlParams);

    expect(spy).to.have.been.calledWith(urlParams);
  });
});
