import sinon from 'sinon';
import { service as terminalsService } from './terminals.js';

const urlParams = {
  affiliationCode: '321321321',
};

const urlParamsWithPagination = {
  affiliationCode: '123123123',
  statusId: 1,
  page: 10,
  pageSize: 2,
};

describe('Terminals Module', () => {
  it('Should have methods after initialization.', () => {
    const service = terminalsService();
    expect(service.get).to.be.a('function');
  });

  it('Should call get request.', () => {
    const spy = sinon.spy();

    const getRequest = () => spy;

    const service = terminalsService(getRequest);

    service.get(urlParams);

    expect(spy).to.have.been.calledOnce;
  });

  it('Should call get request and return a valid URL.', () => {
    const spy = sinon.spy();

    const getRequest = (makeUrl) => {
      spy(makeUrl(urlParams));
      return () => {};
    };

    const service = terminalsService(getRequest);

    service.get(urlParams);

    expect(spy).to.have.been
      .calledWith('v0/merchants/321321321/terminal-devices?page=1&pageSize=30');
  });

  it('Should call get request when paged and return a valid URL.', () => {
    const spy = sinon.spy();

    const getRequest = (makeUrl) => {
      spy(makeUrl(urlParamsWithPagination));
      return () => {};
    };

    const service = terminalsService(getRequest);

    service.get(urlParamsWithPagination);

    expect(spy).to.have.been
      .calledWith('v0/merchants/123123123/terminal-devices' +
        '?page=10&pageSize=2&statusId=1');
  });

  it('Should call get request with valid params.', () => {
    const spy = sinon.spy();

    const getRequest = () => spy;

    const service = terminalsService(getRequest);

    service.get(urlParams);

    expect(spy).to.have.been.calledWith(urlParams);
  });

  it('Should call get request with valid params and pagination.', () => {
    const spy = sinon.spy();

    const getRequest = () => spy;

    const service = terminalsService(getRequest);

    service.get(urlParamsWithPagination);

    expect(spy).to.have.been.calledWith(urlParamsWithPagination);
  });
});
