import sinon from 'sinon';
import { service as info } from './info.js';

const urlParams = {
  id: 321321321,
};

const urlParams2 = {
  id: 5327056609,
};

describe('Product Raio X info Module', () => {
  it('Should have methods after initialization.', () => {
    const service = info();
    expect(service.get).to.be.a('function');
  });

  it('Should call get request.', () => {
    const spy = sinon.spy();

    const getRequest = () => spy;

    const service = info(getRequest);

    service.get(urlParams);

    expect(spy).to.have.been.calledOnce;
  });

  it('Should call get request and return a valid URL.', () => {
    const spy = sinon.spy();

    const getRequest = (makeUrl) => {
      spy(makeUrl(urlParams));
      return () => {};
    };

    const service = info(getRequest);

    service.get(urlParams);

    expect(spy).to.have.been
      .calledWith('v0/products/raio-x/321321321/info');
  });

  it('Should call get request with valid params.', () => {
    const spy = sinon.spy();

    const getRequest = () => spy;

    const service = info(getRequest);

    service.get(urlParams);

    expect(spy).to.have.been.calledWith(urlParams);
  });

  it('Should call get request sent only with id number.', () => {
    const spy = sinon.spy();

    const getRequest = () => spy;

    const service = info(getRequest);

    service.get(urlParams2);

    expect(spy).to.have.been.calledOnce;
  });

  it('Should call get request sent with id and return a valid URL.', () => {
    const spy = sinon.spy();

    const getRequest = (makeUrl) => {
      spy(makeUrl(urlParams2));
      return () => {};
    };

    const service = info(getRequest);

    service.get(urlParams2);

    expect(spy).to.have.been
      .calledWith('v0/products/raio-x/5327056609/info');
  });

  it('Should call get request with only document number.', () => {
    const spy = sinon.spy();

    const getRequest = () => spy;

    const service = info(getRequest);

    service.get(urlParams2);

    expect(spy).to.have.been.calledWith(urlParams2);
  });
});
