import sinon from 'sinon';
import { service as realtimeService } from './realtime.js';

const urlParams = {
  affiliationKeys: '321321321ABCD',
};

const urlParamsWithLimit = {
  affiliationKeys: '123123123ABCD,321321321ABCD',
  limit: 2,
};

describe('Realtime Module', () => {
  it('Should have methods after initialization.', () => {
    const service = realtimeService();
    expect(service.get).to.be.a('function');
  });

  it('Should call get request.', () => {
    const spy = sinon.spy();

    const getRequest = () => spy;

    const service = realtimeService(getRequest);

    service.get(urlParams);

    expect(spy).to.have.been.calledOnce;
  });

  it('Should call get request and return a valid URL.', () => {
    const spy = sinon.spy();

    const getRequest = (makeUrl) => {
      spy(makeUrl(urlParams));
      return () => {};
    };

    const service = realtimeService(getRequest);

    service.get(urlParams);

    expect(spy).to.have.been
      .calledWith('v0/transactions/real-time?affiliationKeys=321321321ABCD');
  });

  it('Should call get request when paged and return a valid URL.', () => {
    const spy = sinon.spy();

    const getRequest = (makeUrl) => {
      spy(makeUrl(urlParamsWithLimit));
      return () => {};
    };

    const service = realtimeService(getRequest);

    service.get(urlParamsWithLimit);

    expect(spy).to.have.been
      .calledWith('v0/transactions/real-time?' +
        'affiliationKeys=123123123ABCD,321321321ABCD&limit=2');
  });

  it('Should call get request with valid params.', () => {
    const spy = sinon.spy();

    const getRequest = () => spy;

    const service = realtimeService(getRequest);

    service.get(urlParams);

    expect(spy).to.have.been.calledWith(urlParams);
  });

  it('Should call get request with valid params and limit.', () => {
    const spy = sinon.spy();

    const getRequest = () => spy;

    const service = realtimeService(getRequest);

    service.get(urlParamsWithLimit);

    expect(spy).to.have.been.calledWith(urlParamsWithLimit);
  });
});
