import sinon from 'sinon';
import { service as tagsService } from './tags.js';

const urlParams = { userEmail: 'test@test.com' };

describe('Tags Module', () => {
  it('Should have methods after initialization.', () => {
    const service = tagsService();
    expect(service.get).to.be.a('function');
  });

  it('Should call get request.', () => {
    const spy = sinon.spy();
    const getRequest = () => spy;
    const service = tagsService(getRequest);

    service.get(urlParams);

    expect(spy).to.have.been.calledOnce;
  });

  it('Should call get request and return a valid URL.', () => {
    const spy = sinon.spy();

    const getRequest = (makeUrl) => {
      spy(makeUrl(urlParams));
      return () => {};
    };

    const service = tagsService(getRequest);

    service.get(urlParams);

    expect(spy).to.have.been
      .calledWith('v0/users/test@test.com/tags');
  });

  it('Should call get request with valid params.', () => {
    const spy = sinon.spy();
    const getRequest = () => spy;
    const service = tagsService(getRequest);

    service.get(urlParams);

    expect(spy).to.have.been.calledWith(urlParams);
  });
});
