import sinon from 'sinon';
import { service as usersList } from './usersList.js';
import { usersListPutInterface, usersListPostInterface } from './usersListInterface.js';

describe('Users List Module', () => {
  let urlParams = {
    limit: 10,
    offset: 1,
  };

  it('Should have methods after initialization.', () => {
    const service = usersList();
    expect(service.get).to.be.a('function');
    expect(service.put).to.be.a('function');
    expect(service.post).to.be.a('function');
  });

  it('Should call get request.', () => {
    const spy = sinon.spy();

    const getRequest = () => spy;

    const service = usersList(getRequest);

    service.get();

    expect(spy).to.have.been.calledOnce;
  });
  it('Should call get request and return a valid URL.', () => {
    const spy = sinon.spy();

    const getRequest = (makeUrl) => {
      spy(makeUrl(urlParams));
      return () => {};
    };

    const service = usersList(getRequest);

    service.get(urlParams);

    expect(spy).to.have.been
      .calledWith('v0/portal/users/visible?offset=1&limit=10');
  });

  it('Should call get request with valid params.', () => {
    const spy = sinon.spy();

    const getRequest = () => spy;

    const service = usersList(getRequest);

    service.get(urlParams);

    expect(spy).to.have.been.calledWith(urlParams);
  });

  it('Should call put request.', () => {
    urlParams = {
      userIdentifier: 123,
    };
    const spy = sinon.spy();

    const putRequest = () => spy;

    const service = usersList(undefined, putRequest);

    service.put(urlParams, usersListPutInterface);

    expect(spy).to.have.been.calledOnce;
  });

  it('Should call put request and return a valid URL.', () => {
    urlParams = {
      userIdentifier: 123,
    };
    const spy = sinon.spy();

    const putRequest = (makeUrl) => {
      spy(makeUrl(urlParams));
      return () => {};
    };

    const service = usersList(undefined, putRequest);

    service.put(urlParams, usersListPutInterface);

    expect(spy).to.have.been
      .calledWith('v0/portal/users/123');
  });

  it('Should call put request with valid params.', () => {
    urlParams = {
      userIdentifier: 123,
    };
    const spy = sinon.spy();

    const putRequest = () => spy;

    const service = usersList(undefined, putRequest);

    service.put(urlParams, usersListPutInterface);

    expect(spy).to.have.been.calledWith(urlParams);
  });

  it('Should call post request.', () => {
    urlParams = {};

    const spy = sinon.spy();

    const postRequest = () => spy;

    const service = usersList(undefined, undefined, postRequest);

    service.post(urlParams, usersListPostInterface);

    expect(spy).to.have.been.calledOnce;
  });

  it('Should call post request and return a valid URL.', () => {
    urlParams = {};

    const spy = sinon.spy();

    const postRequest = (urlString) => {
      spy(urlString);
      return () => {};
    };

    const service = usersList(undefined, undefined, postRequest);

    service.post(urlParams, usersListPostInterface);

    expect(spy).to.have.been.calledOnceWith('v0/portal/users');
  });

  it('Should call post request with valid params.', () => {
    urlParams = {};

    const spy = sinon.spy();

    const postRequest = () => spy;

    const service = usersList(undefined, undefined, postRequest);

    service.post(urlParams);

    expect(spy).to.have.been.calledOnceWith(urlParams);
  });
});
