import { matchesInterface } from '../../../helpers/interface.js';
import { usersListPutInterface, usersListPostInterface } from './usersListInterface.js';

describe('Users List Models', () => {
  it('Should validate the payload according to the interface.', () => {
    const payload = {
      firstName: 'Nome',
      lastName: 'Sobrenome',
      cpf: '12345678900',
      tokenLifeMinutes: 10,
      status: 'Active',
      stoneCodes: [
        '123456789',
        '987654321',
      ],
      permissions: [
        'PERMISSION_1',
        'PERMISSION_2',
        'PERMISSION_3',
      ],
    };
    expect(matchesInterface(usersListPutInterface)(payload))
      .to.be.true;
  });

  it('Should pass with empty arrays.', () => {
    const payload = {
      firstName: 'Nome',
      lastName: 'Sobrenome',
      cpf: '12345678900',
      tokenLifeMinutes: 10,
      status: 'Active',
      stoneCodes: [],
      permissions: [],
    };
    expect(matchesInterface(usersListPutInterface)(payload))
      .to.be.true;
  });

  it('Should validate the payload according to the interface.', () => {
    const payload = {
      firstName: 'Nome',
      lastName: 'Sobrenome',
      fullName: 'Nome completo',
      email: 'test@test.com',
      cpf: '12345678900',
      tokenLifeMinutes: 10,
      status: 'Active',
      role: 'Role',
      stoneCodes: [
        '123456789',
        '987654321',
      ],
      permissions: [
        'PERMISSION_1',
        'PERMISSION_2',
        'PERMISSION_3',
      ],
    };
    expect(matchesInterface(usersListPostInterface)(payload))
      .to.be.true;
  });

  it('Should pass with empty arrays.', () => {
    const payload = {
      firstName: 'Nome',
      lastName: 'Sobrenome',
      fullName: 'Nome completo',
      email: 'test@test.com',
      cpf: '',
      tokenLifeMinutes: 10,
      status: 'Active',
      role: 'Role',
      stoneCodes: [],
      permissions: [],
    };
    expect(matchesInterface(usersListPostInterface)(payload))
      .to.be.true;
  });
});
