import {
  get as getAuthorization,
  set as setAuthorization,
  remove as removeAuthorization,
} from './authorization.js';

import {
  append as appendToHeaders,
  remove as removeFromHeaders,
} from './headers.js';

describe('Authorization Service', () => {
  beforeEach(() => {
    removeFromHeaders('Authorization');
  });

  it('Should get Authorization from Headers when defined.', () => {
    appendToHeaders('Authorization', 'Bearer xyz123456');
    expect(getAuthorization()).to.equal('Bearer xyz123456');
  });

  it('Should set Authorization to Headers.', () => {
    appendToHeaders('Authorization', 'Bearer xyz123456');
    setAuthorization('Basic', 'abc123');
    expect(getAuthorization()).to.equal('Basic abc123');
  });

  it('Should not set Authorization when parameters are not passed.', () => {
    appendToHeaders('Authorization', 'Basic start5678');
    setAuthorization();
    expect(getAuthorization()).to.equal('Basic start5678');
  });

  it('Should remove Authorization from Headers.', () => {
    appendToHeaders('Authorization', 'Basic start5678');
    removeAuthorization();
    expect(getAuthorization()).to.be.undefined;
  });
});
